@@ -2,18 +2,17 @@
 # We will remove the Linear Layer and create a new Linear Layer with num_classes
 # Port from pytorch_cnn_trainer https://github.com/oke-aditya/pytorch_cnn_trainer
 
-import torchvision
-from quickvision.models import components
+from quickvision.models.components import create_torchvision_backbone
 import torch.nn as nn
 
-__all__ = ["vision_cnn", "create_vision_cnn"]
+__all__ = ["CNN", "create_cnn"]
 
 
-class vision_cnn(nn.Module):
+class CNN(nn.Module):
     def __init__(self, model_name: str, num_classes: int, pretrained: str = None):
         super().__init__()
         self.num_classes = num_classes
-        self.bottom, self.out_channels = components.create_torchvision_backbone(model_name, pretrained)
+        self.bottom, self.out_channels = create_torchvision_backbone(model_name, pretrained)
         self.top = nn.Linear(self.out_channels, self.num_classes)
 
     def forward(self, x):
@@ -22,8 +21,8 @@ class vision_cnn(nn.Module):
         return x
 
 
-def create_vision_cnn(model_name: str, num_classes: int,
-                      pretrained: str = None,):
+def create_cnn(model_name: str, num_classes: int,
+               pretrained: str = None,):
 
     # We do not pass in_channels here since torchvision models is not supported with it.
 
@@ -34,5 +33,5 @@ def create_vision_cnn(model_name: str, num_classes: int,
         num_classes (int) : Number of classes for classification.
         pretrained (str) : Pretrained weights dataset "imagenet", etc
     """
-    model = vision_cnn(model_name, num_classes, pretrained)
+    model = CNN(model_name, num_classes, pretrained)
     return model
